.. _queue_module:

:mod:`kazoo.recipe.queue`
-------------------------

.. automodule:: kazoo.recipe.queue

.. versionadded:: 0.6
    The Queue class.

.. versionadded:: 1.0
    The LockingQueue class.

Public API
++++++++++

    .. autoclass:: Queue
        :members:
        :inherited-members:

        .. automethod:: __init__
        .. automethod:: __len__

    .. autoclass:: LockingQueue
        :members:
        :inherited-members:

        .. automethod:: __init__
        .. automethod:: __len__
